/**
 * Honk 1.3 Plays one or more of the Standard Windows sounds, triggered
 * purely from the command line.
 *
 * use:
 *
 * honk
 *    - Plays the default system sound.
 *
 * honk  SystemStart SystemHand SystemQuestion
 *    - Plays the given list of standard system sounds (usually just one).
 *
 * Possible sound names are listed in the registry under:
 *      HKEY_CURRENT_USER/AppEvents/EventLabels.
 *
 * e.g.
 * Close
 * Open
 * Maximize
 * Minimize
 * MenuCommand
 * RestoreDown
 * RestoreUp
 * EmptyRecycleBin
 * SystemAsterisk
 * SystemHand
 * SystemExclamation
 * SystemExit
 * SystemStart
 * SystemQuestion
 *
 *
 * You can view the list with regedit.  Not all of them are necessarily
 * hooked up to real sounds.
 *
 * These are NOT the same as the names in the control panel or the names
 * of the *.wav files.
 *
 * Honk is much faster than using mplayer or player. Nothing appears on the
 * screen. It will not hang up if several copies try to play at once.
 *
 * version 1.3 - embed new Barker address.
 *
 * version 1.2 - made library static so don't need separate Borland DLLs.
 * Compile as a Borland Win32 Owl app with a static library, link no debug, and
 * OWL libraries with a honk.def file like this:
 *
 *  NAME 'Honk'
 *
 *  DESCRIPTION 'Honk - Copyright  1998,1999 Canadian Mind Products.'
 *  EXETYPE     WINDOWS
 *  CODE        PRELOAD MOVEABLE DISCARDABLE
 *  DATA        PRELOAD MOVEABLE
 *
 * There is no honk.rc file.
 *
 * By Roedy Green Canadian Mind Products, roedy@mindprod.com.  May be freely
 * distributed and used for any purpose but military.
 *
 */

/*
Roedy Green
Canadian Mind Products
#208 - 525 Ninth Street
New Westminster BC Canada
V5H 2N6
tel:(604) 777-1804
mailto:roedy@mindprod.com
http://mindprod.com
*/


#include <owl/pch.h>
#include <windows.h>

/**
 * Main analyses the command line to pick off sound names, and plays them
 * then exits. There is no user interface.
 */
int OwlMain(int argc , char* argv [])
{
  if ( argc <= 1 )
    {
    sndPlaySound("SystemDefault", SND_SYNC);
    } else for ( int i=1; i<argc; i++ )
      {
      sndPlaySound(argv[i], SND_SYNC);
      }
  return 0;
}  // end OwlMain

/**
 * copyright and usage banner.  Not displayed, just embedded.
 */
void Banner(void)
{

  static const char* banner =
    ("\nHonk 1.3\n"
     "\nFreeware to make system sounds."
     "\nCopyright (c) 1998 Canadian Mind Products"
     "\n" "#208 - 525 Ninth Street, New Westminster, BC Canada V3M 5T9"
     "\n" "tel:(604) 777-1804   mailto:roedy@mindprod.com   http://mindprod.com"
     "\n" "May be used freely for non-military use only"
     "\n"
     "\n"
     "\nUse:"
     "\nhonk SystemStart SystemHand SystemQuestion"
     "\n     plays given list of standard system sounds."
     "\n     See registry HKEY_CURRENT_USER/AppEvents/EventLabels for names."
     "\n"
    );

} // Banner
// end honk
